package com.huiju.welcome.controller;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.welcome.common.base.BaseController;
import com.huiju.welcome.common.base.ResponseBean;
import com.huiju.welcome.model.TaVisitingWords;
import com.huiju.welcome.service.ITaVisitingWordsService;
import com.huiju.welcome.utils.StatusUtils;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.http.HttpStatus;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.Map;

/**
 * <p>
 *  前端控制器
 * </p>
 *
 * @author jobob
 * @since 2019-03-12
 */
@RestController
@RequestMapping("/")
public class TaVisitingWordsController extends BaseController {
    @Autowired
    ITaVisitingWordsService taVisitingWordsService;

    @ApiOperation(value = "新增欢迎词", notes = "新增欢迎词")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", dataType = "String", name = "deviceId", value = "设备ID"),
            @ApiImplicitParam(paramType = "body", dataType = "Integer", name = "typeId", value = "人员类型ID"),
            @ApiImplicitParam(paramType = "body", dataType = "String", name = "typeName", value = "人员类型名称"),
            @ApiImplicitParam(paramType = "body", dataType = "String", name = "words", value = "欢迎语"),
    })
    @RequestMapping(value = "/visiting_words", method = RequestMethod.POST)
    public ResponseBean create(@RequestBody TaVisitingWords taVisitingWords, HttpServletRequest request) {
        ResponseBean responseBean = new ResponseBean();

        taVisitingWords.setStatus(StatusUtils.Normal);
        boolean success = taVisitingWordsService.save(taVisitingWords);
        if (!success) {
            responseBean.addError(HttpStatus.SC_INTERNAL_SERVER_ERROR, "新增内容失败, 请重试");
            return responseBean;
        }

        responseBean.addSuccess(taVisitingWords);
        return responseBean;
    }

    @ApiOperation(value = "更新欢迎词", notes = "更新欢迎词")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", dataType = "String", name = "deviceId", value = "设备ID"),
            @ApiImplicitParam(paramType = "body", dataType = "Integer", name = "typeId", value = "人员类型ID"),
            @ApiImplicitParam(paramType = "body", dataType = "String", name = "typeName", value = "人员类型名称"),
            @ApiImplicitParam(paramType = "body", dataType = "String", name = "words", value = "欢迎语"),
    })
    @RequestMapping(value = "/visiting_words", method = RequestMethod.PUT)
    public ResponseBean update(@RequestBody TaVisitingWords taVisitingWords, HttpServletRequest request) {
        ResponseBean responseBean = new ResponseBean();

        taVisitingWords.setStatus(StatusUtils.Normal);
        QueryWrapper<TaVisitingWords> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("device_id", taVisitingWords.getDeviceId());
        queryWrapper.eq("type_id", taVisitingWords.getTypeId());

        boolean success = taVisitingWordsService.update(taVisitingWords, queryWrapper);
        if (!success) {
            responseBean.addError(HttpStatus.SC_INTERNAL_SERVER_ERROR, "更新内容失败, 请重试");
            return responseBean;
        }

        responseBean.addSuccess(taVisitingWords);
        return responseBean;
    }


    @ApiOperation(value = "删除欢迎词", notes = "删除欢迎词")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", dataType = "String", name = "deviceId", value = "设备ID"),
            @ApiImplicitParam(paramType = "path", dataType = "Integer", name = "typeId", value = "人员类型ID")
    })
    @RequestMapping(value = "/visiting_words/device/{deviceId}/type/{typeId}", method = RequestMethod.DELETE)
    public ResponseBean delete(@PathVariable String deviceId, @PathVariable int typeId, HttpServletRequest request) {
        ResponseBean responseBean = new ResponseBean();

        Map<String, Object> mp = new HashMap<>();
        mp.put("device_id", deviceId);
        mp.put("type_id", typeId);

        boolean success = taVisitingWordsService.removeByMap(mp);
        if (!success) {
            responseBean.addError(HttpStatus.SC_INTERNAL_SERVER_ERROR, "删除内容失败, 请重试");
            return responseBean;
        }

        return responseBean;
    }

    @ApiOperation(value = "获取欢迎词", notes = "获取欢迎词")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", dataType = "String", name = "deviceId", value = "设备ID"),
            @ApiImplicitParam(paramType = "path", dataType = "Integer", name = "typeId", value = "人员类型ID")
    })
    @RequestMapping(value = "/visiting_words/device/{deviceId}/type/{typeId}", method = RequestMethod.GET)
    public ResponseBean get(@PathVariable String deviceId, @PathVariable int typeId, HttpServletRequest request) {
        ResponseBean responseBean = new ResponseBean();

        QueryWrapper<TaVisitingWords> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("device_id", deviceId);
        queryWrapper.eq("type_id", typeId);

        TaVisitingWords taVisitingWords = taVisitingWordsService.getOne(queryWrapper);
        if (null == taVisitingWords || taVisitingWords.getStatus().intValue() == StatusUtils.Delete) {
            responseBean.addError(HttpStatus.SC_NOT_FOUND, "未找到内容, 请重试");
            return responseBean;
        }

        responseBean.addSuccess(taVisitingWords);
        return responseBean;
    }

    @ApiOperation(value = "获取欢迎词", notes = "获取欢迎词")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "query", dataType = "int", name = "pageNum", value = "当前页"),
            @ApiImplicitParam(paramType = "query", dataType = "int", name = "pageSize", value = "每页数量"),
            @ApiImplicitParam(paramType = "query", dataType = "String", name = "deviceId", value = "设备ID"),
    })
    @RequestMapping(value = "/visiting_words", method = RequestMethod.GET)
    public ResponseBean list(@RequestParam Integer pageNum, @RequestParam  Integer pageSize, @RequestParam String deviceId, HttpServletRequest request) {
        ResponseBean responseBean = new ResponseBean();

        Page<TaVisitingWords> pg = new Page<>();
        pg.setCurrent(pageNum);
        pg.setSize(pageSize);
        QueryWrapper<TaVisitingWords> queryWrapper = new QueryWrapper<>();
        queryWrapper.orderByDesc("device_id");
        queryWrapper.orderByAsc("type_id");
        queryWrapper.eq("status", StatusUtils.Normal);
        if (null != deviceId || !"".equals(deviceId)) {
            queryWrapper.eq("device_id", deviceId);
        }

        responseBean.addSuccess(taVisitingWordsService.page(pg, queryWrapper));

        return responseBean;
    }
}
